@@ -1,4 +1,4 @@
-from mmaze.generator.base import BaseMazeGenerator
+from mmaze.generator.base import BaseMazeGenerator, set_cell
 from mmaze.maze import Maze
 from mmaze.cell import CellType
 
@@ -11,16 +11,14 @@ class Backtracking(BaseMazeGenerator):
     3. If all adjacent cells have been visited, back up to the previous and repeat step 2.
     4. Stop when the algorithm has backed all the way up to the starting cell.
     """
+    symmetry_ok = True
 
-    def __init__(self):
-        super().__init__()  # create empty grid, with walls
-
-    def generate(self, width: int, height: int) -> Maze:
+    def _generate(self, width: int, height: int, symmetry: str = "none") -> Maze:
         m = Maze(width, height, cell_type=CellType.WALL)
 
         row, col = m.random_position()
-        track = [(row, col)]
-        m.set(row, col, CellType.ROAD)
+        track = []
+        set_cell(m, (row, col), CellType.ROAD, symmetry, track)
 
         while track:
             (row, col) = track[-1]
@@ -30,9 +28,7 @@ class Backtracking(BaseMazeGenerator):
                 track = track[:-1]
             else:
                 row_, col_ = neighbors[0]
-                m.set(row_, col_, CellType.ROAD)
-                m.set((row_ + row) // 2, (col_ + col) // 2, CellType.ROAD)
-
-                track += [(row_, col_)]
+                set_cell(m, (row_, col_), CellType.ROAD, symmetry, track)
+                set_cell(m, ((row_ + row) // 2, (col_ + col) // 2), CellType.ROAD, symmetry)
 
         return m
